Module sse_tap

Module sse_tap 

Split the upstream byte stream so that every chunk is sent to the HTTP client without buffering AND a clone of every chunk is delivered to a background reassembler that produces the final JSON message used by the capture record.

Functions

reassemble
Drain the tap stream into the provider-specific reassembler, then return the final reassembled JSON message (when available), the frame count, and an optional partial-capture error.
tee
Splits an upstream byte stream into:

Type Aliases

ClientChunk
One item of the client-side stream returned by tee.
TapReceiver